Determines the default value of the sandbox argument of make_request().
Sandbox mode is enabled by default, so that requests never reach the
production warehouse unless it is explicitly turned off. It is disabled when
the csiapps.sandbox R option is set to FALSE, or, if that option is
unset, when the CSIAPPS_ENV environment variable equals "production".
The R option, when set, always takes precedence over the environment
variable.
See also
csiapps-sandbox for an overview of sandbox mode