Provides a consistent navbar and footer, and handles authentication redirects.
Usage
ui_wrapper(..., sandbox = is_sandbox_mode())Arguments
- ...
Additional UI elements to include in the main content area
- sandbox
If TRUE, a "sandbox mode" banner is shown so it is obvious the app is not connected to the live warehouse. Defaults to
is_sandbox_mode(). See csiapps-sandbox.